function out = popmat(theta)
   
% Return the population matrix (25*25); 25 stages:
%1: prebreeder PB age 0 (=chick)
%2: prebreeder PB age 1
%3: prebreeder PB age 2 
%4: prebreeder PB age 3
%5: prebreeder PB age 4
%6: prebreeder PB age 5
%7: prebreeder PB age 6
%8: prebreeder PB age 7
%9: prebreeder PB age 8
%10: prebreeder PB age 9 and older
%11: Successful first-time breeder SB1 age 5
%12: Successful first-time breeder SB1 age 6
%13: Successful first-time breeder SB1 age 7
%14: Successful first-time breeder SB1 age 8
%15: Successful first-time breeder SB1 age 9
%16: Successful first-time breeder SB1 age 10 and older
%17: Failed first-time breeder FB1 age 5
%18: Failed first-time breeder FB1 age 6
%19: Failed first-time breeder FB1 age 7
%20: Failed first-time breeder FB1 age 8
%21: Failed first-time breeder FB1 age 9
%22: Failed first-time breeder FB1 age 10 and older
%23: Successful breeders SB
%24: Failed breeders FB
%25: Skippers SK

%Parameters
% Survival: 
%   theta 1: survival probability PB from fledging to 1; 
%   theta 2: survival probability PB from age 1 to age 2; 
%   theta 3: survival probability PB from age 2 to age 3; 
%   theta 4: survival probability PB from age 3 to age 4; 
%   theta 5: survival probability PB from age 4 to age 5; 
%   theta 6: survival probability PB from age 5 to age 6; 
%   theta 7: survival probability PB from age 6 to age 7; 
%   theta 8: survival probability PB from age 7 to age 8; 
%   theta 9: survival probability PB from age 8 to age 9; 
%   theta 10: survival probability PB from age 9 onwards; 
%   theta 11: survival probability successful first-time breeders from age 5 to age 6; 
%   theta 12: survival probability successful first-time breeders from age 6 to age 7; 
%   theta 13: survival probability successful first-time breeders from age 7 to age 8; 
%   theta 14: survival probability successful first-time breeders from age 8 to age 9; 
%   theta 15: survival probability successful first-time breeders from age 9 to age 10; 
%   theta 16: survival probability successful first-time breeders from age 10 onwards; 
%   theta 17: survival probability failed first-time breeders from age 5 to age 6; 
%   theta 18: survival probability failed first-time breeders from age 6 to age 7; 
%   theta 19: survival probability failed first-time breeders from age 7 to age 8; 
%   theta 20: survival probability failed first-time breeders from age 8 to age 9; 
%   theta 21: survival probability failed first-time breeders from age 9 to age 10; 
%   theta 22: survival probability failed first-time breeders from age 10 onwards; 
%   theta 23: Annual survival probability successful experienced breeders; 
%   theta 24: Annual survival probability failed experienced breeders; 
%   theta 25: Annual survival probability skippers; 
% Recruitment=breeding proba of PB: 
%   theta 26: recruitment probability at age 5; 
%   theta 27: recruitment probability at age 6; 
%   theta 28: recruitment probability at age 7; 
%   theta 29: recruitment probability at age 8; 
%   theta 30: recruitment probability at age 9; 
%   theta 31: recruitment probability from age 10 onwards;
%Success of PB: 
%   theta 32: given ind recruits at age 5, probability it raises sucessfully a chick;
%   theta 33: given ind recruits at age 6, probability it raises sucessfully a chick;
%   theta 34: given ind recruits at age 7, probability it raises sucessfully a chick;
%   theta 35: given ind recruits at age 8, probability it raises sucessfully a chick;
%   theta 36: given ind recruits at age 9, probability it raises sucessfully a chick;
%   theta 37: given ind recruits from age 10 onwards, probability it raises sucessfully a chick;

%probability of breeding
%   theta 38: Probability a 5 year-old successful first-time breeder at t breeds at t+1;
%   theta 39: Probability a 6 year-old successful first-time breeder at t breeds at t+1;
%   theta 40: Probability a 7 year-old successful first-time breeder at t breeds at t+1;
%   theta 41: Probability a 8 year-old successful first-time breeder at t breeds at t+1;
%   theta 42: Probability a 9 year-old successful first-time breeder at t breeds at t+1;
%   theta 43: Probability a 10 year-old or older successful first-time breeder at t breeds at t+1;
%   theta 44: Probability a 5 year-old failed first-time breeder at t breeds at t+1;
%   theta 45: Probability a 6 year-old failed first-time breeder at t breeds at t+1;
%   theta 46: Probability a 7 year-old failed first-time breeder at t breeds at t+1;
%   theta 47: Probability a 8 year-old failed first-time breeder at t breeds at t+1;
%   theta 48: Probability a 9 year-old failed first-time breeder at t breeds at t+1;
%   theta 49: Probability a 10 year-old or older failed first-time breeder at t breeds at t+1;
%   theta 50: probability that a successful experienced breeder at t breeds at t+1; 
%   theta 51: probability that a failed experienced breeder at t breeds at t+1; 
%   theta 52: probability that a skipper at t breeds at t+1;
% probability of Success:
%   theta 53: probability that a 5 year old successful breeder at t raises sucessfully a chick at t+1; 
%   theta 54: probability that a 6 year old successful breeder at t raises successfully a chick at t+1; 
%   theta 55: probability that a 7 year old successful breeder at t raises sucessfully a chick at t+1;
%   theta 56: probability that a 8 year old successful breeder at t raises sucessfully a chick at t+1; 
%   theta 57: probability that a 9 year old successful breeder at t raises sucessfully a chick at t+1; 
%   theta 58: probability that a 10 year old or older successful breeder at t raises sucessfully a chick at t+1; 
%   theta 59: probability that a 5 year old failed breeder at t raises sucessfully a chick at t+1; 
%   theta 60: probability that a 6 year old failed breeder at t raises sucessfully a chick at t+1; 
%   theta 61: probability that a 7 year old failed breeder at t raises sucessfully a chick at t+1; 
%   theta 62: probability that a 8 year old failed breeder at t raises sucessfully a chick at t+1; 
%   theta 63: probability that a 9 year old failed breeder at t raises sucessfully a chick at t+1; 
%   theta 64: probability that a 10 year old or older failed breeder at t raises sucessfully a chick at t+1; 
%   theta 65: probability that a successful experienced breeder at t raises sucessfully a chick at t+1; 
%   theta 66: probability that a failed experienced breeder at t raises sucessfully a chick at t+1; 
%   theta 67: probability that a skipper at t raises sucessfully a chick at t+1; 
%sex ratio
% Theta 68: fecundity per females = sex ratio (because individuals breed in pairs)

A=zeros(25,25);

% Prebreeding transition
A(2,1)=theta(1); % sigma 1
A(3,2)=theta(2); % sigma 2
A(4,3)=theta(3); % sigma 3
A(5,4)=theta(4); % sigma 4

% Recrutment transitions
A(11,5)=theta(5)*theta(26)*theta(32); % sigma 5* beta 5* gamma 5
A(12,6)=theta(6)*theta(27)*theta(33);
A(13,7)=theta(7)*theta(28)*theta(34);
A(14,8)=theta(8)*theta(29)*theta(35);
A(15,9)=theta(9)*theta(30)*theta(36);
A(16,10)=theta(10)*theta(31)*theta(37);

A(17,5)=theta(5)*theta(26)*(1-theta(32)); % sigma 5* beta 5* (1-gamma 5)
A(18,6)=theta(6)*theta(27)*(1-theta(33));
A(19,7)=theta(7)*theta(28)*(1-theta(34));
A(20,8)=theta(8)*theta(29)*(1-theta(35));
A(21,9)=theta(9)*theta(30)*(1-theta(36));
A(22,10)=theta(10)*theta(31)*(1-theta(37));

A(6,5)=theta(5)*(1-theta(26));% sigma 5* (1-beta 5)
A(7,6)=theta(6)*(1-theta(27));
A(8,7)=theta(7)*(1-theta(28));
A(9,8)=theta(8)*(1-theta(29));
A(10,9)=theta(9)*(1-theta(30));
A(10,10)=theta(10)*(1-theta(31));

% transition from inexperienced S to experienced breeders S
A(23,11)=theta(11)*theta(38)*theta(53); % sigma 11* beta 11* gamma 11
A(23,12)=theta(12)*theta(39)*theta(54);
A(23,13)=theta(13)*theta(40)*theta(55);
A(23,14)=theta(14)*theta(41)*theta(56);
A(23,15)=theta(15)*theta(42)*theta(57);
A(23,16)=theta(16)*theta(43)*theta(58); % sigma 16* beta 16* gamma 16

% transition from inexperienced F to experienced breeders S

A(23,17)=theta(17)*theta(44)*theta(59); % sigma 17* beta 17* gamma 17
A(23,18)=theta(18)*theta(45)*theta(60);
A(23,19)=theta(19)*theta(46)*theta(61);
A(23,20)=theta(20)*theta(47)*theta(62);
A(23,21)=theta(21)*theta(48)*theta(63);
A(23,22)=theta(22)*theta(49)*theta(64);% sigma 22* beta 22* gamma 22

% transition among experienced  breeders to experienced breeders S
A(23,23)=theta(23)*theta(50)*theta(65);
A(23,24)=theta(24)*theta(51)*theta(66);
A(23,25)=theta(25)*theta(52)*theta(67);

% transition from inexperienced S to experienced breeders F
A(24,11)=theta(11)*theta(38)*(1-theta(53)); % sigma 11* beta 11* (1-gamma 11)
A(24,12)=theta(12)*theta(39)*(1-theta(54));
A(24,13)=theta(13)*theta(40)*(1-theta(55));
A(24,14)=theta(14)*theta(41)*(1-theta(56));
A(24,15)=theta(15)*theta(42)*(1-theta(57));
A(24,16)=theta(16)*theta(43)*(1-theta(58));

% transition from inexperienced F to experienced breeders F
A(24,17)=theta(17)*theta(44)*(1-theta(59));
A(24,18)=theta(18)*theta(45)*(1-theta(60));
A(24,19)=theta(19)*theta(46)*(1-theta(61));
A(24,20)=theta(20)*theta(47)*(1-theta(62));
A(24,21)=theta(21)*theta(48)*(1-theta(63));
A(24,22)=theta(22)*theta(49)*(1-theta(64));

% transition among experienced  breeders to experienced breeders F
A(24,23)=theta(23)*theta(50)*(1-theta(65));
A(24,24)=theta(24)*theta(51)*(1-theta(66));
A(24,25)=theta(25)*theta(52)*(1-theta(67));

% transition from inexperienced S to experienced NON breeders 

A(25,11)=theta(11)*(1-theta(38)); % sigma 11* (1-beta 11)
A(25,12)=theta(12)*(1-theta(39));
A(25,13)=theta(13)*(1-theta(40));
A(25,14)=theta(14)*(1-theta(41));
A(25,15)=theta(15)*(1-theta(42));
A(25,16)=theta(16)*(1-theta(43));

% transition from inexperienced F to experienced NON breeders 
A(25,17)=theta(17)*(1-theta(44));
A(25,18)=theta(18)*(1-theta(45));
A(25,19)=theta(19)*(1-theta(46));
A(25,20)=theta(20)*(1-theta(47));
A(25,21)=theta(21)*(1-theta(48));
A(25,22)=theta(22)*(1-theta(49));


% transition among experienced  breeders to experienced NON breeders 
A(25,23)=theta(23)*(1-theta(50));
A(25,24)=theta(24)*(1-theta(51));
A(25,25)=theta(25)*(1-theta(52));


% FECUNDITY

A(1,5)=theta(5)*theta(26)*theta(32)*theta(68); % sigma 5* beta 5* gamma 5 * rho
A(1,6)=theta(6)*theta(27)*theta(33)*theta(68);
A(1,7)=theta(7)*theta(28)*theta(34)*theta(68);
A(1,8)=theta(8)*theta(29)*theta(35)*theta(68);
A(1,9)=theta(9)*theta(30)*theta(36)*theta(68);
A(1,10)=theta(10)*theta(31)*theta(37)*theta(68);
A(1,11)=theta(11)*theta(38)*theta(53)*theta(68); % sigma 11* beta 11* gamma 11* rho
A(1,12)=theta(12)*theta(39)*theta(54)*theta(68);
A(1,13)=theta(13)*theta(40)*theta(55)*theta(68);
A(1,14)=theta(14)*theta(41)*theta(56)*theta(68);
A(1,15)=theta(15)*theta(42)*theta(57)*theta(68);
A(1,16)=theta(16)*theta(43)*theta(58)*theta(68); % sigma 16* beta 16* gamma 16* rho
A(1,17)=theta(17)*theta(44)*theta(59)*theta(68); % sigma 17* beta 17* gamma 17* rho
A(1,18)=theta(18)*theta(45)*theta(60)*theta(68);
A(1,19)=theta(19)*theta(46)*theta(61)*theta(68);
A(1,20)=theta(20)*theta(47)*theta(62)*theta(68);
A(1,21)=theta(21)*theta(48)*theta(63)*theta(68);
A(1,22)=theta(22)*theta(49)*theta(64)*theta(68);% sigma 22* beta 22* gamma 22* rho
A(1,23)=theta(23)*theta(50)*theta(65)*theta(68);
A(1,24)=theta(24)*theta(51)*theta(66)*theta(68);
A(1,25)=theta(25)*theta(52)*theta(67)*theta(68);


% transition matrix

out.A=A;

return